@@ -7,7 +7,7 @@ import sys
 
 
 def find_path():
-    lib_paths = [ os.path.abspath('C:/M/B/src/build-CLANGARM64/lib'), abspath(join(dirname(dirname(sys.argv[0])), '../../../lib')) ]
+    lib_paths = [ os.path.abspath('C:/W/B/src/build-CLANGARM64/lib'), abspath(join(dirname(dirname(sys.argv[0])), '../../../lib')) ]
     possible_libs = ['libflann.so', 'flann.dll', 'libflann.dll', 'libflann.dylib']
 
     for path in lib_paths:
